Class: Google::Cloud::Eventarc::Publishing::V1::CloudEvent::CloudEventAttributeValue

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb

Overview

The following abstract data types are available for use in attributes.

Instance Attribute Summary collapse

Instance Attribute Details

#ce_boolean::Boolean

Returns Boolean value.

Note: The following fields are mutually exclusive: ce_boolean, ce_integer, ce_string, ce_bytes, ce_uri, ce_uri_ref, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    Boolean value.

    Note: The following fields are mutually exclusive: ce_boolean, ce_integer, ce_string, ce_bytes, ce_uri, ce_uri_ref, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.



107
108
109
110
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 107

class CloudEventAttributeValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ce_bytes::String

Returns Bytes value.

Note: The following fields are mutually exclusive: ce_bytes, ce_boolean, ce_integer, ce_string, ce_uri, ce_uri_ref, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Bytes value.

    Note: The following fields are mutually exclusive: ce_bytes, ce_boolean, ce_integer, ce_string, ce_uri, ce_uri_ref, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.



107
108
109
110
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 107

class CloudEventAttributeValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ce_integer::Integer

Returns Integer value.

Note: The following fields are mutually exclusive: ce_integer, ce_boolean, ce_string, ce_bytes, ce_uri, ce_uri_ref, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Integer)

    Integer value.

    Note: The following fields are mutually exclusive: ce_integer, ce_boolean, ce_string, ce_bytes, ce_uri, ce_uri_ref, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.



107
108
109
110
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 107

class CloudEventAttributeValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ce_string::String

Returns String value.

Note: The following fields are mutually exclusive: ce_string, ce_boolean, ce_integer, ce_bytes, ce_uri, ce_uri_ref, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    String value.

    Note: The following fields are mutually exclusive: ce_string, ce_boolean, ce_integer, ce_bytes, ce_uri, ce_uri_ref, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.



107
108
109
110
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 107

class CloudEventAttributeValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ce_timestamp::Google::Protobuf::Timestamp

Returns Timestamp value.

Note: The following fields are mutually exclusive: ce_timestamp, ce_boolean, ce_integer, ce_string, ce_bytes, ce_uri, ce_uri_ref. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::Timestamp)

    Timestamp value.

    Note: The following fields are mutually exclusive: ce_timestamp, ce_boolean, ce_integer, ce_string, ce_bytes, ce_uri, ce_uri_ref. If a field in that set is populated, all other fields in the set will automatically be cleared.



107
108
109
110
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 107

class CloudEventAttributeValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ce_uri::String

Returns URI value.

Note: The following fields are mutually exclusive: ce_uri, ce_boolean, ce_integer, ce_string, ce_bytes, ce_uri_ref, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    URI value.

    Note: The following fields are mutually exclusive: ce_uri, ce_boolean, ce_integer, ce_string, ce_bytes, ce_uri_ref, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.



107
108
109
110
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 107

class CloudEventAttributeValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#ce_uri_ref::String

Returns URI-reference value.

Note: The following fields are mutually exclusive: ce_uri_ref, ce_boolean, ce_integer, ce_string, ce_bytes, ce_uri, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    URI-reference value.

    Note: The following fields are mutually exclusive: ce_uri_ref, ce_boolean, ce_integer, ce_string, ce_bytes, ce_uri, ce_timestamp. If a field in that set is populated, all other fields in the set will automatically be cleared.



107
108
109
110
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 107

class CloudEventAttributeValue
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end