Class: Google::Cloud::Eventarc::Publishing::V1::CloudEvent
- Inherits:
-
Object
- Object
- Google::Cloud::Eventarc::Publishing::V1::CloudEvent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb
Overview
CloudEvent represents a vendor-neutral specification for defining the format of event data.
Defined Under Namespace
Classes: AttributesEntry, CloudEventAttributeValue
Instance Attribute Summary collapse
-
#attributes ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Eventarc::Publishing::V1::CloudEvent::CloudEventAttributeValue}
Optional.
-
#binary_data ⇒ ::String
Optional.
-
#id ⇒ ::String
Required.
-
#proto_data ⇒ ::Google::Protobuf::Any
Optional.
-
#source ⇒ ::String
Required.
-
#spec_version ⇒ ::String
Required.
-
#text_data ⇒ ::String
Optional.
-
#type ⇒ ::String
Required.
Instance Attribute Details
#attributes ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Eventarc::Publishing::V1::CloudEvent::CloudEventAttributeValue}
Returns Optional. Used for Optional & Extension Attributes.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 67 class CloudEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The following abstract data types are available for use in attributes. # @!attribute [rw] ce_boolean # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_integer # @return [::Integer] # Integer value. # # Note: The following fields are mutually exclusive: `ce_integer`, `ce_boolean`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_string # @return [::String] # String value. # # Note: The following fields are mutually exclusive: `ce_string`, `ce_boolean`, `ce_integer`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_bytes # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `ce_bytes`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri # @return [::String] # URI value. # # Note: The following fields are mutually exclusive: `ce_uri`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri_ref # @return [::String] # URI-reference value. # # Note: The following fields are mutually exclusive: `ce_uri_ref`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_timestamp # @return [::Google::Protobuf::Timestamp] # Timestamp value. # # Note: The following fields are mutually exclusive: `ce_timestamp`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`. If a field in that set is populated, all other fields in the set will automatically be cleared. class CloudEventAttributeValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::Publishing::V1::CloudEvent::CloudEventAttributeValue] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#binary_data ⇒ ::String
Returns Optional. Binary data.
Note: The following fields are mutually exclusive: binary_data, text_data, proto_data. If a field in that set is populated, all other fields in the set will automatically be cleared.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 67 class CloudEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The following abstract data types are available for use in attributes. # @!attribute [rw] ce_boolean # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_integer # @return [::Integer] # Integer value. # # Note: The following fields are mutually exclusive: `ce_integer`, `ce_boolean`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_string # @return [::String] # String value. # # Note: The following fields are mutually exclusive: `ce_string`, `ce_boolean`, `ce_integer`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_bytes # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `ce_bytes`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri # @return [::String] # URI value. # # Note: The following fields are mutually exclusive: `ce_uri`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri_ref # @return [::String] # URI-reference value. # # Note: The following fields are mutually exclusive: `ce_uri_ref`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_timestamp # @return [::Google::Protobuf::Timestamp] # Timestamp value. # # Note: The following fields are mutually exclusive: `ce_timestamp`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`. If a field in that set is populated, all other fields in the set will automatically be cleared. class CloudEventAttributeValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::Publishing::V1::CloudEvent::CloudEventAttributeValue] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#id ⇒ ::String
Returns Required. Identifies the event. Producers MUST ensure that source + id is unique for each distinct event.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 67 class CloudEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The following abstract data types are available for use in attributes. # @!attribute [rw] ce_boolean # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_integer # @return [::Integer] # Integer value. # # Note: The following fields are mutually exclusive: `ce_integer`, `ce_boolean`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_string # @return [::String] # String value. # # Note: The following fields are mutually exclusive: `ce_string`, `ce_boolean`, `ce_integer`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_bytes # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `ce_bytes`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri # @return [::String] # URI value. # # Note: The following fields are mutually exclusive: `ce_uri`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri_ref # @return [::String] # URI-reference value. # # Note: The following fields are mutually exclusive: `ce_uri_ref`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_timestamp # @return [::Google::Protobuf::Timestamp] # Timestamp value. # # Note: The following fields are mutually exclusive: `ce_timestamp`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`. If a field in that set is populated, all other fields in the set will automatically be cleared. class CloudEventAttributeValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::Publishing::V1::CloudEvent::CloudEventAttributeValue] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#proto_data ⇒ ::Google::Protobuf::Any
Returns Optional. Proto data.
NOTE: The protoData field only functions as expected when the payload
is specifically a CloudEvent message type, and can't be used for
arbitrary protocol buffer messages. For any other protocol buffer type,
you must serialize your proto message into bytes, and use the
binaryData field instead.
Note: The following fields are mutually exclusive: proto_data, binary_data, text_data. If a field in that set is populated, all other fields in the set will automatically be cleared.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 67 class CloudEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The following abstract data types are available for use in attributes. # @!attribute [rw] ce_boolean # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_integer # @return [::Integer] # Integer value. # # Note: The following fields are mutually exclusive: `ce_integer`, `ce_boolean`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_string # @return [::String] # String value. # # Note: The following fields are mutually exclusive: `ce_string`, `ce_boolean`, `ce_integer`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_bytes # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `ce_bytes`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri # @return [::String] # URI value. # # Note: The following fields are mutually exclusive: `ce_uri`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri_ref # @return [::String] # URI-reference value. # # Note: The following fields are mutually exclusive: `ce_uri_ref`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_timestamp # @return [::Google::Protobuf::Timestamp] # Timestamp value. # # Note: The following fields are mutually exclusive: `ce_timestamp`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`. If a field in that set is populated, all other fields in the set will automatically be cleared. class CloudEventAttributeValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::Publishing::V1::CloudEvent::CloudEventAttributeValue] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#source ⇒ ::String
Returns Required. Identifies the context in which an event happened. URI-reference.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 67 class CloudEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The following abstract data types are available for use in attributes. # @!attribute [rw] ce_boolean # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_integer # @return [::Integer] # Integer value. # # Note: The following fields are mutually exclusive: `ce_integer`, `ce_boolean`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_string # @return [::String] # String value. # # Note: The following fields are mutually exclusive: `ce_string`, `ce_boolean`, `ce_integer`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_bytes # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `ce_bytes`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri # @return [::String] # URI value. # # Note: The following fields are mutually exclusive: `ce_uri`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri_ref # @return [::String] # URI-reference value. # # Note: The following fields are mutually exclusive: `ce_uri_ref`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_timestamp # @return [::Google::Protobuf::Timestamp] # Timestamp value. # # Note: The following fields are mutually exclusive: `ce_timestamp`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`. If a field in that set is populated, all other fields in the set will automatically be cleared. class CloudEventAttributeValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::Publishing::V1::CloudEvent::CloudEventAttributeValue] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#spec_version ⇒ ::String
Returns Required. The version of the CloudEvents specification which the event uses.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 67 class CloudEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The following abstract data types are available for use in attributes. # @!attribute [rw] ce_boolean # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_integer # @return [::Integer] # Integer value. # # Note: The following fields are mutually exclusive: `ce_integer`, `ce_boolean`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_string # @return [::String] # String value. # # Note: The following fields are mutually exclusive: `ce_string`, `ce_boolean`, `ce_integer`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_bytes # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `ce_bytes`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri # @return [::String] # URI value. # # Note: The following fields are mutually exclusive: `ce_uri`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri_ref # @return [::String] # URI-reference value. # # Note: The following fields are mutually exclusive: `ce_uri_ref`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_timestamp # @return [::Google::Protobuf::Timestamp] # Timestamp value. # # Note: The following fields are mutually exclusive: `ce_timestamp`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`. If a field in that set is populated, all other fields in the set will automatically be cleared. class CloudEventAttributeValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::Publishing::V1::CloudEvent::CloudEventAttributeValue] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#text_data ⇒ ::String
Returns Optional. Text data.
Note: The following fields are mutually exclusive: text_data, binary_data, proto_data. If a field in that set is populated, all other fields in the set will automatically be cleared.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 67 class CloudEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The following abstract data types are available for use in attributes. # @!attribute [rw] ce_boolean # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_integer # @return [::Integer] # Integer value. # # Note: The following fields are mutually exclusive: `ce_integer`, `ce_boolean`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_string # @return [::String] # String value. # # Note: The following fields are mutually exclusive: `ce_string`, `ce_boolean`, `ce_integer`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_bytes # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `ce_bytes`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri # @return [::String] # URI value. # # Note: The following fields are mutually exclusive: `ce_uri`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri_ref # @return [::String] # URI-reference value. # # Note: The following fields are mutually exclusive: `ce_uri_ref`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_timestamp # @return [::Google::Protobuf::Timestamp] # Timestamp value. # # Note: The following fields are mutually exclusive: `ce_timestamp`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`. If a field in that set is populated, all other fields in the set will automatically be cleared. class CloudEventAttributeValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::Publishing::V1::CloudEvent::CloudEventAttributeValue] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#type ⇒ ::String
Returns Required. This attribute contains a value describing the type of event related to the originating occurrence.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'proto_docs/google/cloud/eventarc/publishing/v1/cloud_event.rb', line 67 class CloudEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The following abstract data types are available for use in attributes. # @!attribute [rw] ce_boolean # @return [::Boolean] # Boolean value. # # Note: The following fields are mutually exclusive: `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_integer # @return [::Integer] # Integer value. # # Note: The following fields are mutually exclusive: `ce_integer`, `ce_boolean`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_string # @return [::String] # String value. # # Note: The following fields are mutually exclusive: `ce_string`, `ce_boolean`, `ce_integer`, `ce_bytes`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_bytes # @return [::String] # Bytes value. # # Note: The following fields are mutually exclusive: `ce_bytes`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_uri`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri # @return [::String] # URI value. # # Note: The following fields are mutually exclusive: `ce_uri`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri_ref`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_uri_ref # @return [::String] # URI-reference value. # # Note: The following fields are mutually exclusive: `ce_uri_ref`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_timestamp`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] ce_timestamp # @return [::Google::Protobuf::Timestamp] # Timestamp value. # # Note: The following fields are mutually exclusive: `ce_timestamp`, `ce_boolean`, `ce_integer`, `ce_string`, `ce_bytes`, `ce_uri`, `ce_uri_ref`. If a field in that set is populated, all other fields in the set will automatically be cleared. class CloudEventAttributeValue include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Eventarc::Publishing::V1::CloudEvent::CloudEventAttributeValue] class AttributesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |