Class: Google::Cloud::Eventarc::Publishing::V1::Publisher::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Eventarc::Publishing::V1::Publisher::Rest::Client
- Defined in:
- lib/google/cloud/eventarc/publishing/v1/publisher/rest/client.rb
Overview
REST client for the Publisher service.
Eventarc processes events generated by an event provider and delivers them to a subscriber.
An event provider is a software-as-a-service (SaaS) system or product that can generate and deliver events through Eventarc.
A third-party event provider is an event provider from outside of Google.
A partner is a third-party event provider that is integrated with Eventarc.
A subscriber is a Google Cloud customer interested in receiving events.
Channel is a first-class Eventarc resource that is created and managed by the subscriber in their Google Cloud project. A Channel represents a subscriber's intent to receive events from an event provider. A Channel is associated with exactly one event provider.
ChannelConnection is a first-class Eventarc resource that is created and managed by the partner in their Google Cloud project. A ChannelConnection represents a connection between a partner and a subscriber's Channel. A ChannelConnection has a one-to-one mapping with a Channel.
Bus is a first-class Eventarc resource that is created and managed in a Google Cloud project. A Bus provides a discoverable endpoint for events and is a router that receives all events published by event providers and delivers them to zero or more subscribers.
Publisher allows an event provider to publish events to Eventarc.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the Publisher Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the Publisher Client instance.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new Publisher REST client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#publish(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Eventarc::Publishing::V1::PublishResponse
Publish events to a message bus.
-
#publish_channel_connection_events(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Eventarc::Publishing::V1::PublishChannelConnectionEventsResponse
Publish events to a ChannelConnection in a partner's project.
-
#publish_events(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Eventarc::Publishing::V1::PublishEventsResponse
Publish events to a subscriber's channel.
-
#universe_domain ⇒ String
The effective universe domain.
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new Publisher REST client object.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/google/cloud/eventarc/publishing/v1/publisher/rest/client.rb', line 157 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @publisher_stub = ::Google::Cloud::Eventarc::Publishing::V1::Publisher::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @publisher_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the Publisher Client class.
See Configuration for a description of the configuration fields.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/google/cloud/eventarc/publishing/v1/publisher/rest/client.rb', line 91 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Eventarc", "Publishing", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.publish_channel_connection_events.timeout = 60.0 default_config.rpcs.publish.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the Publisher Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
127 128 129 130 |
# File 'lib/google/cloud/eventarc/publishing/v1/publisher/rest/client.rb', line 127 def configure yield @config if block_given? @config end |
#logger ⇒ Logger
The logger used for request/response debug logging.
204 205 206 |
# File 'lib/google/cloud/eventarc/publishing/v1/publisher/rest/client.rb', line 204 def logger @publisher_stub.logger end |
#publish(request, options = nil) ⇒ ::Google::Cloud::Eventarc::Publishing::V1::PublishResponse #publish(message_bus: nil, proto_message: nil, json_message: nil, avro_message: nil) ⇒ ::Google::Cloud::Eventarc::Publishing::V1::PublishResponse
Publish events to a message bus.
448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/google/cloud/eventarc/publishing/v1/publisher/rest/client.rb', line 448 def publish request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Eventarc::Publishing::V1::PublishRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.publish..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Eventarc::Publishing::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.publish.timeout, metadata: , retry_policy: @config.rpcs.publish.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @publisher_stub.publish request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#publish_channel_connection_events(request, options = nil) ⇒ ::Google::Cloud::Eventarc::Publishing::V1::PublishChannelConnectionEventsResponse #publish_channel_connection_events(channel_connection: nil, events: nil, text_events: nil) ⇒ ::Google::Cloud::Eventarc::Publishing::V1::PublishChannelConnectionEventsResponse
Publish events to a ChannelConnection in a partner's project.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/google/cloud/eventarc/publishing/v1/publisher/rest/client.rb', line 263 def publish_channel_connection_events request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Eventarc::Publishing::V1::PublishChannelConnectionEventsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.publish_channel_connection_events..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Eventarc::Publishing::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.publish_channel_connection_events.timeout, metadata: , retry_policy: @config.rpcs.publish_channel_connection_events.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @publisher_stub.publish_channel_connection_events request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#publish_events(request, options = nil) ⇒ ::Google::Cloud::Eventarc::Publishing::V1::PublishEventsResponse #publish_events(channel: nil, events: nil, text_events: nil) ⇒ ::Google::Cloud::Eventarc::Publishing::V1::PublishEventsResponse
Publish events to a subscriber's channel.
351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/google/cloud/eventarc/publishing/v1/publisher/rest/client.rb', line 351 def publish_events request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Eventarc::Publishing::V1::PublishEventsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.publish_events..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Eventarc::Publishing::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.publish_events.timeout, metadata: , retry_policy: @config.rpcs.publish_events.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @publisher_stub.publish_events request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
137 138 139 |
# File 'lib/google/cloud/eventarc/publishing/v1/publisher/rest/client.rb', line 137 def universe_domain @publisher_stub.universe_domain end |